@@ -1,13 +1,17 @@
 #ifndef _MAIN_H_
 #define _MAIN_H_
 
+#include <stdlib.h>
 #include <string.h>
 
 #include <hildon/hildon.h>
 #include <libsoup/soup.h>
+#include <conic.h>
 
 #include <json-glib/json-glib.h>
 
+#include <espeak/speak_lib.h>
+
 /* global variables */
 HildonProgram* program;
 GtkWidget* window;
@@ -27,6 +31,10 @@ GtkWidget* hbox_bottom;
 GtkWidget* button_paste;
 GtkWidget* button_translate;
 GtkWidget* button_copy;
+GtkWidget* button_clear1;
+GtkWidget* button_clear2;
+GtkWidget* button_say1;
+GtkWidget* button_say2;
 
 GtkWidget* vbox_main;
 
@@ -48,21 +56,25 @@ extern gint settings_int_get(gchar* group, gchar* key, gint default_value);
 extern void create_window();
 
 /* callbacks.c */
-extern void translate(GtkWidget* button, gpointer data);
+extern void connect_internet(GtkWidget* widget, gpointer data);
+extern void translate();
 extern void change_language(GtkWidget* button, gpointer data);
 extern void show_alert(gchar* text);
 extern void show_about(GtkWidget* widget, gpointer data);
 extern void swap_languages(GtkWidget* widget, gpointer data);
 extern void paste_text(GtkWidget* widget, gpointer data);
 extern void copy_text(GtkWidget* widget, gpointer data);
+extern void clear_text(GtkWidget* widget, gint data);
+extern void say_text(GtkWidget* widget, gint data);
 
 typedef struct
 {
 	char* str_short;
 	char* str_long;
+	gboolean espeak;
 } language;
 
-extern language languages[51];
-GdkPixbuf* flags[51];
+extern language languages[52];
+GdkPixbuf* flags[52];
 
 #endif // _MAIN_H_
